@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11530 2019-05-08 18:38:01Z Lavender $
+# $Id: models.py 11720 2019-09-23 06:12:17Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-05-09 03:38:01 +0900 (週四, 09 五月 2019) $
-# $Revision: 11530 $
+# $Date: 2019-09-23 14:12:17 +0800 (週一, 23 九月 2019) $
+# $Revision: 11720 $
 
 from drip import models
 from drip import utils
@@ -75,24 +75,25 @@ class DripBase2(drips.DripBase):
         MessageClass = drips.message_class_for(self.drip_model.message_class)
 
         count = 0
-        for user in self.get_queryset():
-            message_instance = MessageClass(self, user)
+        for obj in self.get_queryset():
+            message_instance = MessageClass(self, obj)
             try:
                 result = message_instance.message.send()
                 if result:
                     SentDrip.objects.create(
                         drip=self.drip_model,
-                        user=user,
+                        objId=obj.id,
                         from_email=self.from_email,
                         from_email_name=self.from_email_name,
+                        reply_to=self.reply_to,
                         subject=message_instance.subject,
                         body=message_instance.body
                     )
                     count += 1
             except Exception as e:
                 logger.error(
-                    "Failed to send drip %s to user %s: %s" % (
-                        self.drip_model.id, user, e))
+                    "Failed to send drip %s to obj %s: %s" % (
+                        self.drip_model.id, obj, e))
         logger.info("Total send: %d emails." %count)
         return count
 
