@@ -144,7 +144,9 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, actionId, formId=None,
     # if not created:
     #     actionRecord.count = actionRecord.count + 1
     actionRecord.save()
-    domain = Site.objects.get_current().domain
+    
+    website = Site.objects.get_current()
+    domain = website.domain
 
     hashedActionId = int_to_hashid(int(actionId))
     link = f"{settings.META_SITE_PROTOCOL}://{domain}{reverse('showTargetFile')}?key={hashedActionId}"
@@ -221,17 +223,22 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, actionId, formId=None,
 
             replaceStr = {
                 'email': email.email,
+                'webName': website.name,
+                'request': request,
             }
             replaceStr.update(fileData)
 
             if not form:
-                title = _settings.CALL_TO_ACTION_EMAIL_SUBJECT
+                title = f'[{website.name}]-{_settings.CALL_TO_ACTION_EMAIL_SUBJECT}'  
 
             else:
-                title = landingForm.email_subject
-
-            mail = get_template('blog_extension/call_to_action/FileConfirm.txt')
-            message = mail.render(replaceStr)
+                title = f'[{website.name}]-{landingForm.email_subject}'
+            
+            
+            from django.template import Context
+            mail = get_template('blog_extension/call_to_action/FileConfirm.txt').template
+            
+            message = mail.render(Context(replaceStr))
             send_mail(
                 title,
                 message,
