@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 12011 2020-03-25 11:01:56Z Lavender $
+# $Id: cms_plugins.py 12012 2020-03-25 11:28:44Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-25 20:01:56 +0900 (週三, 25 三月 2020) $
-# $Revision: 12011 $
+# $Date: 2020-03-25 19:28:44 +0800 (週三, 25 三月 2020) $
+# $Revision: 12012 $
 
 import re
 import requests
@@ -28,11 +28,14 @@ from django.utils.safestring import mark_safe
 from django.template.loader import select_template
 from django.urls import reverse
 
+from Iuppiter.Logging import createLogger
 from Zephyrus.facebook import settings as zephyrusSettings
 from Zephyrus.facebook.models import (
     FacebookFan, FacebookPhoto, ShareLike, FacebookSettings)
 from Zephyrus.facebook.models import FanPage as FanPageModel
 
+logger = createLogger(__name__)
+
 class Subattachment(object):
     def __init__(self, title, subattachmentType, img, url):
         self.title = title
@@ -113,64 +116,68 @@ def getFanPageId(accessToken, url):
         return None
         
 def getFanPage(url, limit):
-    # get data
-    req = requests.get("%sposts/?ref=page_internal&_fb_noscript=1" % url)  
-    content = req.text
-    soup = BeautifulSoup(content, 'html.parser')
-    
-    # create object
-    fpList = []
-    for i, div in enumerate(soup.find_all('div', class_="_4-u2 _4-u8"), 1):
-        pageId = i
+    try:
+        # get data
+        req = requests.get("%sposts/?ref=page_internal&_fb_noscript=1" % url)  
+        content = req.text
+        soup = BeautifulSoup(content, 'html.parser')
         
-        # createdTime
-        createdTime = div.find_all('span', class_="timestampContent")[0].text
-        
-        # message
-        msg = div.find_all('div', class_='text_exposed_root')
-        if msg:
-            msg = mark_safe(str(div.find_all('div', class_='text_exposed_root')[0]))
-        else:
-            msg = div.find_all('div', {'data-testid': 'post_message'})
-            if msg:
-                TextWithBackground = msg[0].find_all('div', {'style':re.compile("background-image")})
-                if TextWithBackground:
-                    # for those text with background, only use extract the text without style
-                    msg = mark_safe(TextWithBackground[0].find_all('span', {'aria-hidden': "true"})[0].text)
-                else:
-                    msg = mark_safe(str(msg[0]))
-            else:
-                msg = ''
-        
-        # image
-        images = div.find_all('img', class_="scaledImageFitWidth img")
-        if images:
-            mainImg = div.find_all('img', class_="scaledImageFitWidth img")[0].get("data-src", "#")
-        else:
-            # there might be more than one picture in one post
-            images = div.find_all('img', class_="scaledImageFitHeight img")
-            if images:
-                mainImg = images[0].get("data-src", "#")
-            else:
-                mainImg = None
-           
-        # type
-        postType = "abc"
-        
-        # link
-        links = div.find_all('a', class_="_5pcq")
-        if links:
-            link = "https://www.facebook.com%s" % div.find_all('a', class_="_5pcq")[0].get("href", "#")
-        else:
-            continue
+        # create object
+        fpList = []
+        for i, div in enumerate(soup.find_all('div', class_="_4-u2 _4-u8"), 1):
+            pageId = i
             
-        subattachments = []
-        fp = FanPage(pageId, createdTime, msg, mainImg, postType, link, subattachments)
-        fpList.append(fp)
-        if len(fpList) == limit:
-            break
-   
-    return fpList
+            # createdTime
+            createdTime = div.find_all('span', class_="timestampContent")[0].text
+            
+            # message
+            msg = div.find_all('div', class_='text_exposed_root')
+            if msg:
+                msg = mark_safe(str(div.find_all('div', class_='text_exposed_root')[0]))
+            else:
+                msg = div.find_all('div', {'data-testid': 'post_message'})
+                if msg:
+                    TextWithBackground = msg[0].find_all('div', {'style':re.compile("background-image")})
+                    if TextWithBackground:
+                        # for those text with background, only use extract the text without style
+                        msg = mark_safe(TextWithBackground[0].find_all('span', {'aria-hidden': "true"})[0].text)
+                    else:
+                        msg = mark_safe(str(msg[0]))
+                else:
+                    msg = ''
+            
+            # image
+            images = div.find_all('img', class_="scaledImageFitWidth img")
+            if images:
+                mainImg = div.find_all('img', class_="scaledImageFitWidth img")[0].get("data-src", "#")
+            else:
+                # there might be more than one picture in one post
+                images = div.find_all('img', class_="scaledImageFitHeight img")
+                if images:
+                    mainImg = images[0].get("data-src", "#")
+                else:
+                    mainImg = None
+               
+            # type
+            postType = "abc"
+            
+            # link
+            links = div.find_all('a', class_="_5pcq")
+            if links:
+                link = "https://www.facebook.com%s" % div.find_all('a', class_="_5pcq")[0].get("href", "#")
+            else:
+                continue
+                
+            subattachments = []
+            fp = FanPage(pageId, createdTime, msg, mainImg, postType, link, subattachments)
+            fpList.append(fp)
+            if len(fpList) == limit:
+                break
+       
+        return fpList
+    except Exception as e:
+        logger.error(str(e))
+        return [] # no post
 
 class FacebookFanPlugin(CMSPluginBase):
     model = FacebookFan
@@ -320,36 +327,40 @@ class FacebookFanPlugin(CMSPluginBase):
             return context
         
 def getFanPhoto(url, limit):
-    # get data
-    req = requests.get(url)  
-    content = req.text
-    startStr = '''"media":{"edges":['''
-    endStr = '''],"page_info":'''
-    content = "[%s]" % content[content.find(startStr) + len(startStr):content.find(endStr)]
-    data = json.loads(content)
-    
-    # create objects
-    photoList = []
-    for d in data:
-        node = d.get("node")
-        if not node:
-            continue
-            
-        name = None
-        url = None
-        link = None
-        if not 'image' in node:
-            continue
-       
-        url = node.get("image", {}).get("uri", '#')
-        #name = mark_safe(node.get("album", {}).get("name", '').replace('\n', '<br />'))
-        link = node.get("url", '#')
+    try:
+        # get data
+        req = requests.get(url)  
+        content = req.text
+        startStr = '''"media":{"edges":['''
+        endStr = '''],"page_info":'''
+        content = "[%s]" % content[content.find(startStr) + len(startStr):content.find(endStr)]
+        data = json.loads(content)
         
-        photoList.append(Photo(name, url, link))
-        if len(photoList) == limit:
-            break
+        # create objects
+        photoList = []
+        for d in data:
+            node = d.get("node")
+            if not node:
+                continue
+                
+            name = None
+            url = None
+            link = None
+            if not 'image' in node:
+                continue
+           
+            url = node.get("image", {}).get("uri", '#')
+            #name = mark_safe(node.get("album", {}).get("name", '').replace('\n', '<br />'))
+            link = node.get("url", '#')
             
-    return photoList
+            photoList.append(Photo(name, url, link))
+            if len(photoList) == limit:
+                break
+                
+        return photoList
+    except Exception as e:
+        logger.error(str(e))
+        return [] # no photo
         
 class FacebookPhotoPlugin(CMSPluginBase):
     model = FacebookPhoto
